@@ -106,7 +106,8 @@ class SimpleValue(_base.BaseValue):
     node, var = self.ctx.attribute_handler.get_attribute(
         node, obj, "__call__", obj_binding)
     if var is not None and var.bindings:
-      return function.call_function(self.ctx, node, var, args)
+      return function.call_function(self.ctx, node, var, args,
+                                    allow_noreturn=True)
     else:
       raise function.NotCallable(self)
 
