@@ -166,8 +166,7 @@ def _compare_tuple(op, left, right):
 
 def _compare_dict(op, left, right):
   # Determines when dicts are definitely not equal by checking their key sets.
-  if (_is_equality_cmp(op) and
-      not left.could_contain_anything and
+  if (_is_equality_cmp(op) and left.is_concrete and
       abstract_utils.is_concrete_dict(right) and
       set(left.pyval) != set(right.pyval)):
     return op != slots.EQ
@@ -184,6 +183,24 @@ def _compare_class(op, left, right):
   raise CmpTypeError()
 
 
+def _compare_sequence_length(
+    op, left: abstract.SequenceLength, right: abstract.ConcreteValue):
+  """Compare sequence lengths for pattern matching."""
+  assert isinstance(right, abstract.ConcreteValue)
+  if op == slots.EQ:
+    if left.splat:
+      return None if left.length <= right.pyval else False
+    else:
+      return left.length == right.pyval
+  elif op == slots.GE:
+    if left.splat:
+      return True if left.length >= right.pyval else None
+    else:
+      return left.length >= right.pyval
+  else:
+    assert False, op
+
+
 def cmp_rel(ctx, op, left, right):
   """Compare two variables."""
   if _is_primitive_constant(ctx, left):
@@ -196,6 +213,8 @@ def cmp_rel(ctx, op, left, right):
     return _compare_dict(op, left, right)
   elif isinstance(left, abstract.Class):
     return _compare_class(op, left, right)
+  elif isinstance(left, abstract.SequenceLength):
+    return _compare_sequence_length(op, left, right)
   else:
     return None
 
@@ -213,9 +232,9 @@ def compatible_with(value, logical_value):
     True: If it is possible for the value to evaluate to the logical_value,
         and any ambiguity cannot be resolved by additional bindings.
   """
-  if isinstance(value, abstract.List) and value.could_contain_anything:
+  if isinstance(value, abstract.List) and not value.is_concrete:
     return True
-  elif isinstance(value, abstract.Dict) and value.could_contain_anything:
+  elif isinstance(value, abstract.Dict) and not value.is_concrete:
     # Always compatible with False. Compatible with True only if type
     # parameters have been established (meaning that the dict can be
     # non-empty).
