@@ -240,11 +240,12 @@ class CallTracer(vm.VirtualMachine):
 
   def analyze_method_var(self, node0, name, var, cls):
     full_name = f"{cls.data.full_name}.{name}"
-    if log.isEnabledFor(logging.INFO):
-      if any(isinstance(v, abstract.INTERPRETER_FUNCTION_TYPES)
-             for v in var.data):
-        log.info("Analyzing method: %r", full_name)
-    node1 = node0.ConnectNew(full_name)
+    if any(isinstance(v, abstract.INTERPRETER_FUNCTION_TYPES)
+           for v in var.data):
+      log.info("Analyzing method: %r", full_name)
+      node1 = self.ctx.connect_new_cfg_node(node0, f"Method:{full_name}")
+    else:
+      node1 = node0
     for val in var.bindings:
       node2 = self.maybe_analyze_method(node1, val, cls)
       node2.ConnectTo(node0)
@@ -290,7 +291,8 @@ class CallTracer(vm.VirtualMachine):
       self._analyzed_functions.add(b.data.get_first_opcode())
       node2, args = self.create_method_arguments(node1, b.data)
       args = self._maybe_fix_classmethod_cls_arg(node0, cls, b.data, args)
-      node3 = node2.ConnectNew()
+      node3 = self.ctx.connect_new_cfg_node(
+          node2, f"Call:{cls.data.name}.__new__")
       node4, ret = self.call_function_with_args(node3, b, args)
       instance.PasteVariable(ret)
       nodes.append(node4)
@@ -345,7 +347,7 @@ class CallTracer(vm.VirtualMachine):
       A tuple of node and instance variable.
     """
     cache = self._instance_cache[cls]
-    key = (self.frame and self.frame.current_opcode, extra_key)
+    key = (self.current_opcode, extra_key)
     status = instance = cache.get(key)
     if not instance or isinstance(instance, _InitClassState):
       clsvar = cls.to_variable(node)
@@ -414,20 +416,21 @@ class CallTracer(vm.VirtualMachine):
       self._call_init_on_binding(node, instance.to_binding(node))
 
   def analyze_class(self, node, val):
-    log.info("Analyzing class: %r", val.data.full_name)
-    self._analyzed_classes.add(val.data)
-    node, instance = self.init_class(node, val.data)
-    good_instances = [b for b in instance.bindings if val.data == b.data.cls]
+    cls = val.data
+    log.info("Analyzing class: %r", cls.full_name)
+    self._analyzed_classes.add(cls)
+    node, instance = self.init_class(node, cls)
+    good_instances = [b for b in instance.bindings if cls == b.data.cls]
     if not good_instances:
       # __new__ returned something that's not an instance of our class.
-      instance = val.data.instantiate(node)
+      instance = cls.instantiate(node)
       node = self.call_init(node, instance)
     elif len(good_instances) != len(instance.bindings):
       # __new__ returned some extra possibilities we don't need.
       instance = self.ctx.join_bindings(node, good_instances)
     for instance_value in instance.data:
-      val.data.register_canonical_instance(instance_value)
-    methods = sorted(val.data.members.items())
+      cls.register_canonical_instance(instance_value)
+    methods = sorted(cls.members.items())
     while methods:
       name, methodvar = methods.pop(0)
       if name in self._CONSTRUCTORS:
@@ -437,6 +440,12 @@ class CallTracer(vm.VirtualMachine):
           for m in (v.fget, v.fset, v.fdel):
             if m:
               methods.insert(0, (name, m))
+        if (not cls.is_abstract and isinstance(v, abstract.Function) and
+            v.is_abstract):
+          unwrapped = abstract_utils.maybe_unwrap_decorated_function(v)
+          name = unwrapped.data[0].name if unwrapped else v.name
+          self.ctx.errorlog.ignored_abstractmethod(
+              self.ctx.vm.simple_stack(cls.get_first_opcode()), cls.name, name)
       b = self.bind_method(node, methodvar, instance)
       node = self.analyze_method_var(node, name, b, val)
     return node
@@ -446,7 +455,7 @@ class CallTracer(vm.VirtualMachine):
       # We'll analyze this function as part of a class.
       log.info("Analyze functions: Skipping class method %s", val.data.name)
     else:
-      node1 = node0.ConnectNew(val.data.name)
+      node1 = self.ctx.connect_new_cfg_node(node0, f"Function:{val.data.name}")
       node2 = self.maybe_analyze_method(node1, val)
       node2.ConnectTo(node0)
     return node0
