@@ -519,7 +519,8 @@ def make_class(node, props, ctx):
     try:
       class_type = props.class_type or abstract.InterpreterClass
       assert issubclass(class_type, abstract.InterpreterClass)
-      val = class_type(name, bases, class_dict.pyval, cls, ctx)
+      val = class_type(
+          name, bases, class_dict.pyval, cls, ctx.vm.current_opcode, ctx)
       _check_final_members(val, class_dict.pyval, ctx)
       overriding_checks.check_overriding_members(val, bases, class_dict.pyval,
                                                  ctx.matcher(node), ctx)
@@ -535,11 +536,6 @@ def make_class(node, props, ctx):
       var.AddBinding(val, props.class_dict_var.bindings, node)
       node = val.call_metaclass_init(node)
       node = val.call_init_subclass(node)
-      if not val.is_abstract:
-        # Since a class decorator could have made the class inherit from
-        # ABCMeta, we have to mark concrete classes now and check for
-        # abstract methods at postprocessing time.
-        ctx.vm.concrete_classes.append((val, ctx.vm.simple_stack()))
   ctx.vm.trace_opcode(None, name, var)
   return node, var
 
@@ -805,7 +801,7 @@ def call_inplace_operator(state, iname, x, y, ctx):
   if attr is None:
     log.info("No inplace operator %s on %r", iname, x)
     name = iname.replace("i", "", 1)  # __iadd__ -> __add__ etc.
-    state = state.forward_cfg_node()
+    state = state.forward_cfg_node(f"BinOp:{name}")
     state, ret = call_binary_operator(
         state, name, x, y, report_errors=True, ctx=ctx)
   else:
@@ -910,9 +906,10 @@ def jump_if(state, op, ctx, pop=False, jump_if_val=False, or_pop=False):
   if jump is not frame_state.UNSATISFIABLE:
     if jump:
       assert jump.binding
-      else_state = state.forward_cfg_node(jump.binding).forward_cfg_node()
+      else_state = state.forward_cfg_node(
+          "Jump", jump.binding).forward_cfg_node("Jump")
     else:
-      else_state = state.forward_cfg_node()
+      else_state = state.forward_cfg_node("Jump")
     ctx.vm.store_jump(op.target, else_state)
   else:
     else_state = None
@@ -924,7 +921,7 @@ def jump_if(state, op, ctx, pop=False, jump_if_val=False, or_pop=False):
   elif not else_state and not normal:
     return state  # We didn't actually branch.
   else:
-    return state.forward_cfg_node(normal.binding if normal else None)
+    return state.forward_cfg_node("NoJump", normal.binding if normal else None)
 
 
 def process_function_type_comment(node, op, func, ctx):
